bayespy.nodes.VaryingGaussianMarkovChain.initialize_from_value
==============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.initialize_from_value